@@ -3,13 +3,15 @@
 # # # # # # # # # # # # # #
 from .utils import bash, python_files_for_commit
 
+DEFAULT = 'on'
 
-def run():
+
+def run(arg=''):
     "Check flake8 errors in the code base."
     py_files = str(python_files_for_commit())
     if not py_files:
         return
-    b = bash("flake8 {0}".format(py_files.replace('\n', ' ')))
+    b = bash("flake8 {0} {1}".format(py_files.replace('\n', ' '), arg))
     if b.err:
         if b"command not found" in b.err:
             return (
